@@ -153,7 +153,7 @@ as.gWidgetsRGtk2.GtkTextView <- function(widget, ...) {
   ##               buffer$createTag(Paste(i,".background"),background = i)
   ##             }
   fontColors <-  colors()
-  sapply(colors(), function(i) {
+  lapply(colors(), function(i) {
     if(is.null(tagtbl$lookup(i))) 
       buffer$createTag(i,foreground = i)
     if(is.null(tagtbl$lookup(Paste(i,".background"))))
